var languageNames = {
"en-US": "English (USA)",
"am": "Amharic",
"ar": "Arabic",
"ast": "Asturian",
"bg": "Bulgarian",
"bn": "Bengali",
"bn-IN": "Bengali (India)",
"bo": "Tibetan",
"bs": "Bosnian",
"ca": "Catalan",
"ca-valencia": "Valencian Catalan",
"cs": "Czech",
"da": "Danish",
"de": "German",
"dz": "Dzongkha",
"el": "Greek",
"en-GB": "English (UK)",
"en-ZA": "English (SA)",
"eo": "Esperanto",
"es": "Spanish",
"et": "Estonian",
"eu": "Basque",
"fi": "Finnish",
"fr": "French",
"gl": "Galician",
"gu": "Gujarati",
"he": "Hebrew",
"hi": "Hindi",
"hr": "Croatian",
"hu": "Hungarian",
"id": "Indonesian",
"is": "Icelandic",
"it": "Italian",
"ja": "Japanese",
"ka": "Georgian",
"km": "Khmer",
"ko": "Korean",
"lo": "Lao",
"lt": "Lithuanian",
"lv": "Latvian",
"mk": "Macedonian",
Binary file /builds/chakra/packages/desktop/libreoffice/src/libreoffice-6.4.1.2/helpcontent2/source/text/shared/help/browserhelp.xhp matches
};
